@@ -1,7 +1,7 @@
 package Neo4j::Bolt::NeoValue;
 
 BEGIN {
-  our $VERSION = "0.4203";
+  our $VERSION = "0.5000";
   require Neo4j::Bolt::CTypeHandlers;
   require Neo4j::Bolt::CResultStream;
   require XSLoader;
@@ -89,6 +89,19 @@ Class method. Syntactic sugar; runs L</"_as_perl()"> on the arguments.
 
 =back
 
+=head1 FUNCTIONS
+
+=over
+
+=item is_bool($scalar)
+
+  $boolean = Neo4j::Bolt::NeoValue::is_bool( $value );
+
+Returns true iff Neo4j::Bolt would treat this Perl value as
+a boolean when found in a query parameter.
+
+=back
+
 =head1 AUTHOR
 
  Mark A. Jensen
@@ -97,7 +110,7 @@ Class method. Syntactic sugar; runs L</"_as_perl()"> on the arguments.
 
 =head1 LICENSE
 
-This software is Copyright (c) 2019-2021 by Mark A. Jensen.
+This software is Copyright (c) 2019-2024 by Mark A. Jensen.
 
 This is free software, licensed under:
 
