@@ -1,20 +1,62 @@
 package Neo4j::Bolt::Relationship;
 # ABSTRACT: Representation of Neo4j Relationship
 
-$Neo4j::Bolt::Relationship::VERSION = '0.4203';
+$Neo4j::Bolt::Relationship::VERSION = '0.5000';
 
 use strict;
 use warnings;
 
 use parent 'Neo4j::Types::Relationship';
 
+sub element_id {
+  my $self = shift;
+  if ($self->{element_id} eq $self->{id}) {
+    warnings::warnif 'Neo4j::Types', 'element_id unavailable';
+    return $self->{id};
+  }
+  return $self->{element_id};
+}
+
+sub start_element_id {
+  my $self = shift;
+  if ($self->{start_element_id} eq $self->{start}) {
+    warnings::warnif 'Neo4j::Types', 'start_element_id unavailable';
+    return $self->{start};
+  }
+  return $self->{start_element_id};
+}
+
+sub end_element_id {
+  my $self = shift;
+  if ($self->{end_element_id} eq $self->{end}) {
+    warnings::warnif 'Neo4j::Types', 'end_element_id unavailable';
+    return $self->{end};
+  }
+  return $self->{end_element_id};
+}
+
+sub id { shift->{id} }
+sub start_id { shift->{start} }
+sub end_id { shift->{end} }
+
+sub type { shift->{type} }
+sub properties { shift->{properties} // {} }
+
+sub get {
+  my $self = shift;
+  my ($property) = @_;
+  return $self->{properties}->{$property};
+}
+
 sub as_simple {
-  my ($self) = @_;
-  
+  my $self = shift;
   my %simple = defined $self->{properties} ? %{$self->{properties}} : ();
   $simple{_relationship} = $self->{id};
+  $simple{_element_id} = $self->{element_id};
   $simple{_start} = $self->{start};
+  $simple{_start_element_id} = $self->{start_element_id};
   $simple{_end} = $self->{end};
+  $simple{_end_element_id} = $self->{end_element_id};
   $simple{_type} = $self->{type};
   return \%simple;
 }
@@ -51,7 +93,7 @@ a Cypher query that returns relationships from a Neo4j database.
 Their properties and metadata can be accessed as shown in the
 synopsis above.
 
-This package inherits from L<Neo4j::Types::Relationship>, which
+This class conforms to the L<Neo4j::Types::Relationship> API, which
 offers an object-oriented interface to the relationship's
 properties and metadata. This is entirely optional to use.
 
@@ -60,7 +102,25 @@ L<Neo4j::Bolt::Relationship> instances will be created.
 
 =head1 METHODS
 
-This package inherits all methods from L<Neo4j::Types::Relationship>.
+This class provides the following methods defined by
+L<Neo4j::Types::Relationship>:
+
+=over
+
+=item * L<B<get()>|Neo4j::Types::Relationship/"get">
+
+=item * L<B<id()>|Neo4j::Types::Relationship/"id">
+
+=item * L<B<properties()>|Neo4j::Types::Relationship/"properties">
+
+=item * L<B<start_id()>|Neo4j::Types::Relationship/"start_id">
+
+=item * L<B<end_id()>|Neo4j::Types::Relationship/"end_id">
+
+=item * L<B<type()>|Neo4j::Types::Relationship/"type">
+
+=back
+
 The following additional method is provided:
 
 =over
@@ -94,7 +154,7 @@ L<Neo4j::Bolt>, L<Neo4j::Types::Relationship>
 
 =head1 LICENSE
 
-This software is Copyright (c) 2020-2021 by Arne Johannessen
+This software is Copyright (c) 2020-2024 by Arne Johannessen
 
 This is free software, licensed under:
 
